@@ -5,8 +5,8 @@ import requests
 import arrow
 import pytz
 
-from getter import PriceGetter
-from crypto_data import crypto_data
+from .core import Service, NoData
+from .crypto_data import crypto_data
 
 quandl_exchange_btc_to_fiat = {
     'ARS': 'localbtc',
@@ -44,8 +44,8 @@ quandl_exchange_btc_to_fiat = {
     'ZAR': 'bitx',
 }
 
-class QuandlHistoricalPriceGetter(PriceGetter):
-    def get_historical(self, crypto, fiat, at_time):
+class Quandl(Service):
+    def get_historical_price(self, crypto, fiat, at_time):
         """
         Using the quandl.com API, get the historical price (by day).
         The CRYPTOCHART source claims to be from multiple exchange sources
@@ -90,9 +90,7 @@ class QuandlHistoricalPriceGetter(PriceGetter):
             at_time - interval, at_time + interval
         )
 
-        if self.verbose: print("URL:", url + trim)
-
-        response = self.fetch_url(url + trim).json()
+        response = self.get_url(url + trim).json()
         closest_distance = interval
 
         best_price = None
@@ -111,9 +109,9 @@ class QuandlHistoricalPriceGetter(PriceGetter):
                 best_date = tick_date
 
         if not best_price:
-            msg = "Data source is incomplete. Could not get best price for %s/%s on %s." % (
+            msg = "Quandl's data source is incomplete. Could not get best price for %s/%s on %s." % (
                 crypto, fiat, at_time
             )
-            raise Exception(msg)
+            raise NoData(msg)
 
         return best_price, source, best_date
